@@ -1,6 +1,5 @@
-from ..interpreter import ConditionBase
+from ..interpreter import ConditionBase, InterpretCommand
 from ..exceptions import CommandSyntaxError
-import commands.interpreter
 
 from typing import Any
 
@@ -31,13 +30,13 @@ class FalseCondition(BooleanCondition):
         return super(FalseCondition, FalseCondition).test(False, *tokens)
 
 def register_default_boolean_conditions() -> None:
-    old_interpreter_init = commands.interpreter.InterpretCommand.__init__
-    def _register_boolean_init_(self: commands.interpreter.InterpretCommand, *args, **kwargs):
+    old_interpreter_init = InterpretCommand.__init__
+    def _register_boolean_init_(self: InterpretCommand, *args, **kwargs):
         old_interpreter_init(self, *args, **kwargs)
         self.register_condition("true", TrueCondition, lambda: None)
         self.register_condition("false", FalseCondition, lambda: None)
 
-    commands.interpreter.InterpretCommand.__init__ = _register_boolean_init_
+    InterpretCommand.__init__ = _register_boolean_init_
 
 
 
